#author-comment-card{margin-bottom:20px;width:80%}#author-comment-card .avatar{vertical-align:top}#author-comment-card .author-comment-info{display:inline-block}#author-comment-card #controls{float:right}#author-comment-card #controls .btn-group{float:right}#author-comment-card #controls .is-moderated{color:#985f0d;clear:both;padding-top:10px}#toggle_soft_delete.delete{color:#fff !important;background:#d9534f !important}#toggle_soft_delete.restore{color:#fff !important;background:#5cb85c !important}
