.comment.unpublished .panel-body{background:url("../img/unpublished.png")}.comment .thumbnail{padding:0}.comment .panel{position:relative}.comment .panel>.panel-heading:after,.comment .panel>.panel-heading:before{position:absolute;top:11px;left:-16px;right:100%;width:0;height:0;display:block;content:" ";border-color:transparent;border-style:solid solid outset;pointer-events:none}.comment .panel>.panel-heading:after{border-width:7px;border-right-color:#f7f7f7;margin-top:1px;margin-left:2px}.comment .panel>.panel-heading:before{border-right-color:#ddd;border-width:8px}.comment pre{border:0;background:transparent;font-family:'Roboto Slab', 'Roboto', serif;margin:0;padding:0}.comment-box textarea{height:150px;max-height:450px}.comment-box .avatar{float:left;padding-bottom:15px;padding-right:15px}.comment-box .dynamic-gravatar{width:100%;max-width:150px}
