
#author-comment-card {

    margin-bottom: 20px;
    .avatar {
        vertical-align: top;
    }

    .author-comment-info {
        display: inline-block;
    }

    #controls {
        float: right;
        .btn-group {
            float: right
        }
        .is-moderated {
            color: #985f0d;
            clear: both;
            padding-top: 10px;
        }
    }

    width: 80%;
}

#toggle_soft_delete {
    &.delete {
        color: #fff !important;
        background: #d9534f !important;
    }

    &.restore {
        color: #fff !important;
        background: #5cb85c !important;
    }
}