/* line 5, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.label {
  display: inline;
  padding: .2em .6em .3em;
  font-size: 75%;
  font-weight: bold;
  line-height: 1;
  color: #fff;
  text-align: center;
  white-space: nowrap;
  vertical-align: baseline;
  border-radius: .25em;
}
/* line 20, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.label:empty {
  display: none;
}
/* line 25, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.btn .label {
  position: relative;
  top: -1px;
}

/* line 33, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
a.label:hover, a.label:focus {
  color: #fff;
  text-decoration: none;
  cursor: pointer;
}

/* line 44, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.label-default {
  background-color: #777777;
}
/* line 7, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_labels.scss */
.label-default[href]:hover, .label-default[href]:focus {
  background-color: #5e5e5e;
}

/* line 48, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.label-primary {
  background-color: #337ab7;
}
/* line 7, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_labels.scss */
.label-primary[href]:hover, .label-primary[href]:focus {
  background-color: #286090;
}

/* line 52, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.label-success {
  background-color: #5cb85c;
}
/* line 7, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_labels.scss */
.label-success[href]:hover, .label-success[href]:focus {
  background-color: #449d44;
}

/* line 56, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.label-info {
  background-color: #5bc0de;
}
/* line 7, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_labels.scss */
.label-info[href]:hover, .label-info[href]:focus {
  background-color: #31b0d5;
}

/* line 60, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.label-warning {
  background-color: #f0ad4e;
}
/* line 7, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_labels.scss */
.label-warning[href]:hover, .label-warning[href]:focus {
  background-color: #ec971f;
}

/* line 64, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_labels.scss */
.label-danger {
  background-color: #d9534f;
}
/* line 7, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_labels.scss */
.label-danger[href]:hover, .label-danger[href]:focus {
  background-color: #c9302c;
}

/* line 1, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn
.btn {
  display: inline-block;
  margin-bottom: 0;
  font-weight: normal;
  text-align: center;
  vertical-align: middle;
  touch-action: manipulation;
  cursor: pointer;
  background-image: none;
  border: 1px solid transparent;
  white-space: nowrap;
  padding: 6px 12px;
  font-size: 14px;
  line-height: 1.42857;
  border-radius: 4px;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
/* line 26, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn
.btn:focus, .btn
.btn.focus, .btn
.btn:active:focus, .btn
.btn:active.focus, .btn
.btn.active:focus, .btn
.btn.active.focus {
  outline: thin dotted;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}
/* line 32, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn
.btn:hover, .btn
.btn:focus, .btn
.btn.focus {
  color: #333;
  text-decoration: none;
}
/* line 39, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn
.btn:active, .btn
.btn.active {
  outline: 0;
  background-image: none;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
/* line 46, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn
.btn.disabled, .btn
.btn[disabled], fieldset[disabled] .btn
.btn {
  cursor: not-allowed;
  opacity: 0.65;
  filter: alpha(opacity=65);
  -webkit-box-shadow: none;
  box-shadow: none;
}

/* line 58, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
a.btn.disabled, fieldset[disabled] a.btn {
  pointer-events: none;
}

/* line 68, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-default {
  color: #333;
  background-color: #fff;
  border-color: #ccc;
}
/* line 11, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-default:focus, .btn-default.focus {
  color: #333;
  background-color: #e6e6e6;
  border-color: #8c8c8c;
}
/* line 17, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-default:hover {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}
/* line 22, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-default:active, .btn-default.active, .open > .btn-default.dropdown-toggle {
  color: #333;
  background-color: #e6e6e6;
  border-color: #adadad;
}
/* line 29, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-default:active:hover, .btn-default:active:focus, .btn-default:active.focus, .btn-default.active:hover, .btn-default.active:focus, .btn-default.active.focus, .open > .btn-default.dropdown-toggle:hover, .open > .btn-default.dropdown-toggle:focus, .open > .btn-default.dropdown-toggle.focus {
  color: #333;
  background-color: #d4d4d4;
  border-color: #8c8c8c;
}
/* line 37, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-default:active, .btn-default.active, .open > .btn-default.dropdown-toggle {
  background-image: none;
}
/* line 45, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-default.disabled:hover, .btn-default.disabled:focus, .btn-default.disabled.focus, .btn-default[disabled]:hover, .btn-default[disabled]:focus, .btn-default[disabled].focus, fieldset[disabled] .btn-default:hover, fieldset[disabled] .btn-default:focus, fieldset[disabled] .btn-default.focus {
  background-color: #fff;
  border-color: #ccc;
}
/* line 53, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-default .badge {
  color: #fff;
  background-color: #333;
}

/* line 71, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-primary {
  color: #fff;
  background-color: #337ab7;
  border-color: #2e6da4;
}
/* line 11, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-primary:focus, .btn-primary.focus {
  color: #fff;
  background-color: #286090;
  border-color: #122b40;
}
/* line 17, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-primary:hover {
  color: #fff;
  background-color: #286090;
  border-color: #204d74;
}
/* line 22, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-primary:active, .btn-primary.active, .open > .btn-primary.dropdown-toggle {
  color: #fff;
  background-color: #286090;
  border-color: #204d74;
}
/* line 29, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-primary:active:hover, .btn-primary:active:focus, .btn-primary:active.focus, .btn-primary.active:hover, .btn-primary.active:focus, .btn-primary.active.focus, .open > .btn-primary.dropdown-toggle:hover, .open > .btn-primary.dropdown-toggle:focus, .open > .btn-primary.dropdown-toggle.focus {
  color: #fff;
  background-color: #204d74;
  border-color: #122b40;
}
/* line 37, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-primary:active, .btn-primary.active, .open > .btn-primary.dropdown-toggle {
  background-image: none;
}
/* line 45, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-primary.disabled:hover, .btn-primary.disabled:focus, .btn-primary.disabled.focus, .btn-primary[disabled]:hover, .btn-primary[disabled]:focus, .btn-primary[disabled].focus, fieldset[disabled] .btn-primary:hover, fieldset[disabled] .btn-primary:focus, fieldset[disabled] .btn-primary.focus {
  background-color: #337ab7;
  border-color: #2e6da4;
}
/* line 53, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-primary .badge {
  color: #337ab7;
  background-color: #fff;
}

/* line 75, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-success {
  color: #fff;
  background-color: #5cb85c;
  border-color: #4cae4c;
}
/* line 11, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-success:focus, .btn-success.focus {
  color: #fff;
  background-color: #449d44;
  border-color: #255625;
}
/* line 17, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-success:hover {
  color: #fff;
  background-color: #449d44;
  border-color: #398439;
}
/* line 22, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-success:active, .btn-success.active, .open > .btn-success.dropdown-toggle {
  color: #fff;
  background-color: #449d44;
  border-color: #398439;
}
/* line 29, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-success:active:hover, .btn-success:active:focus, .btn-success:active.focus, .btn-success.active:hover, .btn-success.active:focus, .btn-success.active.focus, .open > .btn-success.dropdown-toggle:hover, .open > .btn-success.dropdown-toggle:focus, .open > .btn-success.dropdown-toggle.focus {
  color: #fff;
  background-color: #398439;
  border-color: #255625;
}
/* line 37, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-success:active, .btn-success.active, .open > .btn-success.dropdown-toggle {
  background-image: none;
}
/* line 45, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-success.disabled:hover, .btn-success.disabled:focus, .btn-success.disabled.focus, .btn-success[disabled]:hover, .btn-success[disabled]:focus, .btn-success[disabled].focus, fieldset[disabled] .btn-success:hover, fieldset[disabled] .btn-success:focus, fieldset[disabled] .btn-success.focus {
  background-color: #5cb85c;
  border-color: #4cae4c;
}
/* line 53, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-success .badge {
  color: #5cb85c;
  background-color: #fff;
}

/* line 79, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-info {
  color: #fff;
  background-color: #5bc0de;
  border-color: #46b8da;
}
/* line 11, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-info:focus, .btn-info.focus {
  color: #fff;
  background-color: #31b0d5;
  border-color: #1b6d85;
}
/* line 17, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-info:hover {
  color: #fff;
  background-color: #31b0d5;
  border-color: #269abc;
}
/* line 22, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-info:active, .btn-info.active, .open > .btn-info.dropdown-toggle {
  color: #fff;
  background-color: #31b0d5;
  border-color: #269abc;
}
/* line 29, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-info:active:hover, .btn-info:active:focus, .btn-info:active.focus, .btn-info.active:hover, .btn-info.active:focus, .btn-info.active.focus, .open > .btn-info.dropdown-toggle:hover, .open > .btn-info.dropdown-toggle:focus, .open > .btn-info.dropdown-toggle.focus {
  color: #fff;
  background-color: #269abc;
  border-color: #1b6d85;
}
/* line 37, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-info:active, .btn-info.active, .open > .btn-info.dropdown-toggle {
  background-image: none;
}
/* line 45, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-info.disabled:hover, .btn-info.disabled:focus, .btn-info.disabled.focus, .btn-info[disabled]:hover, .btn-info[disabled]:focus, .btn-info[disabled].focus, fieldset[disabled] .btn-info:hover, fieldset[disabled] .btn-info:focus, fieldset[disabled] .btn-info.focus {
  background-color: #5bc0de;
  border-color: #46b8da;
}
/* line 53, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-info .badge {
  color: #5bc0de;
  background-color: #fff;
}

/* line 83, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-warning {
  color: #fff;
  background-color: #f0ad4e;
  border-color: #eea236;
}
/* line 11, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-warning:focus, .btn-warning.focus {
  color: #fff;
  background-color: #ec971f;
  border-color: #985f0d;
}
/* line 17, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-warning:hover {
  color: #fff;
  background-color: #ec971f;
  border-color: #d58512;
}
/* line 22, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-warning:active, .btn-warning.active, .open > .btn-warning.dropdown-toggle {
  color: #fff;
  background-color: #ec971f;
  border-color: #d58512;
}
/* line 29, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-warning:active:hover, .btn-warning:active:focus, .btn-warning:active.focus, .btn-warning.active:hover, .btn-warning.active:focus, .btn-warning.active.focus, .open > .btn-warning.dropdown-toggle:hover, .open > .btn-warning.dropdown-toggle:focus, .open > .btn-warning.dropdown-toggle.focus {
  color: #fff;
  background-color: #d58512;
  border-color: #985f0d;
}
/* line 37, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-warning:active, .btn-warning.active, .open > .btn-warning.dropdown-toggle {
  background-image: none;
}
/* line 45, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-warning.disabled:hover, .btn-warning.disabled:focus, .btn-warning.disabled.focus, .btn-warning[disabled]:hover, .btn-warning[disabled]:focus, .btn-warning[disabled].focus, fieldset[disabled] .btn-warning:hover, fieldset[disabled] .btn-warning:focus, fieldset[disabled] .btn-warning.focus {
  background-color: #f0ad4e;
  border-color: #eea236;
}
/* line 53, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-warning .badge {
  color: #f0ad4e;
  background-color: #fff;
}

/* line 87, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-danger {
  color: #fff;
  background-color: #d9534f;
  border-color: #d43f3a;
}
/* line 11, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-danger:focus, .btn-danger.focus {
  color: #fff;
  background-color: #c9302c;
  border-color: #761c19;
}
/* line 17, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-danger:hover {
  color: #fff;
  background-color: #c9302c;
  border-color: #ac2925;
}
/* line 22, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-danger:active, .btn-danger.active, .open > .btn-danger.dropdown-toggle {
  color: #fff;
  background-color: #c9302c;
  border-color: #ac2925;
}
/* line 29, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-danger:active:hover, .btn-danger:active:focus, .btn-danger:active.focus, .btn-danger.active:hover, .btn-danger.active:focus, .btn-danger.active.focus, .open > .btn-danger.dropdown-toggle:hover, .open > .btn-danger.dropdown-toggle:focus, .open > .btn-danger.dropdown-toggle.focus {
  color: #fff;
  background-color: #ac2925;
  border-color: #761c19;
}
/* line 37, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-danger:active, .btn-danger.active, .open > .btn-danger.dropdown-toggle {
  background-image: none;
}
/* line 45, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-danger.disabled:hover, .btn-danger.disabled:focus, .btn-danger.disabled.focus, .btn-danger[disabled]:hover, .btn-danger[disabled]:focus, .btn-danger[disabled].focus, fieldset[disabled] .btn-danger:hover, fieldset[disabled] .btn-danger:focus, fieldset[disabled] .btn-danger.focus {
  background-color: #d9534f;
  border-color: #d43f3a;
}
/* line 53, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_buttons.scss */
.btn-danger .badge {
  color: #d9534f;
  background-color: #fff;
}

/* line 96, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-link {
  color: #337ab7;
  font-weight: normal;
  border-radius: 0;
}
/* line 101, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-link, .btn-link:active, .btn-link.active, .btn-link[disabled], fieldset[disabled] .btn-link {
  background-color: transparent;
  -webkit-box-shadow: none;
  box-shadow: none;
}
/* line 109, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-link, .btn-link:hover, .btn-link:focus, .btn-link:active {
  border-color: transparent;
}
/* line 115, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-link:hover, .btn-link:focus {
  color: #23527c;
  text-decoration: underline;
  background-color: transparent;
}
/* line 123, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-link[disabled]:hover, .btn-link[disabled]:focus, fieldset[disabled] .btn-link:hover, fieldset[disabled] .btn-link:focus {
  color: #777777;
  text-decoration: none;
}

/* line 135, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-lg, .btn-group-lg > .btn {
  padding: 10px 16px;
  font-size: 18px;
  line-height: 1.33333;
  border-radius: 6px;
}

/* line 139, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-sm, .btn-group-sm > .btn {
  padding: 5px 10px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}

/* line 143, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-xs, .btn-group-xs > .btn {
  padding: 1px 5px;
  font-size: 12px;
  line-height: 1.5;
  border-radius: 3px;
}

/* line 151, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-block {
  display: block;
  width: 100%;
}

/* line 157, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
.btn-block + .btn-block {
  margin-top: 5px;
}

/* line 165, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_buttons.scss */
input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
  width: 100%;
}

/* line 6, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group,
.btn-group-vertical {
  position: relative;
  display: inline-block;
  vertical-align: middle;
}
/* line 11, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn,
.btn-group-vertical > .btn {
  position: relative;
  float: left;
}
/* line 15, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn:hover, .btn-group > .btn:focus, .btn-group > .btn:active, .btn-group > .btn.active,
.btn-group-vertical > .btn:hover,
.btn-group-vertical > .btn:focus,
.btn-group-vertical > .btn:active,
.btn-group-vertical > .btn.active {
  z-index: 2;
}

/* line 26, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group .btn + .btn,
.btn-group .btn + .btn-group,
.btn-group .btn-group + .btn,
.btn-group .btn-group + .btn-group {
  margin-left: -1px;
}

/* line 35, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-toolbar {
  margin-left: -5px;
}
/* line 14, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_clearfix.scss */
.btn-toolbar:before, .btn-toolbar:after {
  content: " ";
  display: table;
}
/* line 19, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_clearfix.scss */
.btn-toolbar:after {
  clear: both;
}
/* line 39, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-toolbar .btn,
.btn-toolbar .btn-group,
.btn-toolbar .input-group {
  float: left;
}
/* line 44, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-toolbar > .btn,
.btn-toolbar > .btn-group,
.btn-toolbar > .input-group {
  margin-left: 5px;
}

/* line 51, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0;
}

/* line 56, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn:first-child {
  margin-left: 0;
}
/* line 58, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

/* line 63, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn:last-child:not(:first-child),
.btn-group > .dropdown-toggle:not(:first-child) {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

/* line 69, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn-group {
  float: left;
}

/* line 72, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
}

/* line 76, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-top-right-radius: 0;
}

/* line 81, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-bottom-left-radius: 0;
  border-top-left-radius: 0;
}

/* line 86, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
  outline: 0;
}

/* line 105, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn + .dropdown-toggle {
  padding-left: 8px;
  padding-right: 8px;
}

/* line 109, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group > .btn-lg + .dropdown-toggle, .btn-group-lg.btn-group > .btn + .dropdown-toggle {
  padding-left: 12px;
  padding-right: 12px;
}

/* line 116, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group.open .dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
  box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}
/* line 120, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group.open .dropdown-toggle.btn-link {
  -webkit-box-shadow: none;
  box-shadow: none;
}

/* line 127, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn .caret {
  margin-left: 0;
}

/* line 131, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-lg .caret, .btn-group-lg > .btn .caret {
  border-width: 5px 5px 0;
  border-bottom-width: 0;
}

/* line 136, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.dropup .btn-lg .caret, .dropup .btn-group-lg > .btn .caret {
  border-width: 0 5px 5px;
}

/* line 145, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn,
.btn-group-vertical > .btn-group,
.btn-group-vertical > .btn-group > .btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
}
/* line 14, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_clearfix.scss */
.btn-group-vertical > .btn-group:before, .btn-group-vertical > .btn-group:after {
  content: " ";
  display: table;
}
/* line 19, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/mixins/_clearfix.scss */
.btn-group-vertical > .btn-group:after {
  clear: both;
}
/* line 157, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn-group > .btn {
  float: none;
}
/* line 162, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn + .btn,
.btn-group-vertical > .btn + .btn-group,
.btn-group-vertical > .btn-group + .btn,
.btn-group-vertical > .btn-group + .btn-group {
  margin-top: -1px;
  margin-left: 0;
}

/* line 172, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn:not(:first-child):not(:last-child) {
  border-radius: 0;
}
/* line 175, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn:first-child:not(:last-child) {
  border-top-right-radius: 4px;
  border-top-left-radius: 4px;
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}
/* line 179, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn:last-child:not(:first-child) {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
  border-bottom-right-radius: 4px;
  border-bottom-left-radius: 4px;
}

/* line 184, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn-group:not(:first-child):not(:last-child) > .btn {
  border-radius: 0;
}

/* line 188, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .btn:last-child,
.btn-group-vertical > .btn-group:first-child:not(:last-child) > .dropdown-toggle {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

/* line 193, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-vertical > .btn-group:last-child:not(:first-child) > .btn:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}

/* line 201, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-justified {
  display: table;
  width: 100%;
  table-layout: fixed;
  border-collapse: separate;
}
/* line 206, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-justified > .btn,
.btn-group-justified > .btn-group {
  float: none;
  display: table-cell;
  width: 1%;
}
/* line 212, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-justified > .btn-group .btn {
  width: 100%;
}
/* line 216, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
.btn-group-justified > .btn-group .dropdown-menu {
  left: auto;
}

/* line 237, ../libs/bootstrap-sass/assets/stylesheets/bootstrap/_button-groups.scss */
[data-toggle="buttons"] > .btn input[type="radio"],
[data-toggle="buttons"] > .btn input[type="checkbox"],
[data-toggle="buttons"] > .btn-group > .btn input[type="radio"],
[data-toggle="buttons"] > .btn-group > .btn input[type="checkbox"] {
  position: absolute;
  clip: rect(0, 0, 0, 0);
  pointer-events: none;
}

/* line 70, ../scss/_light-bootstrap.scss */
#author-comment-card .btn {
  padding: 6px 12px !important;
  font-size: 14px !important;
  line-height: 1.42857 !important;
  border-radius: 4px !important;
}
/* line 74, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-group > .btn:first-child:not(:last-child):not(.dropdown-toggle) {
  border-bottom-right-radius: 0 !important;
  border-top-right-radius: 0 !important;
}
/* line 79, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-group > .btn:last-child:not(:first-child), #author-comment-card .btn-group > .dropdown-toggle:not(:first-child) {
  border-bottom-left-radius: 0 !important;
  border-top-left-radius: 0 !important;
}
/* line 84, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-group > .btn:not(:first-child):not(:last-child):not(.dropdown-toggle) {
  border-radius: 0 !important;
}
/* line 88, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-default {
  color: #333 !important;
  background-color: #fff !important;
  border-color: #ccc !important;
}
/* line 12, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-default:focus, #author-comment-card .btn-default.focus {
  color: #333 !important;
  background-color: #e6e6e6 !important;
  border-color: #8c8c8c !important;
}
/* line 18, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-default:hover {
  color: #333 !important;
  background-color: #e6e6e6 !important;
  border-color: #adadad;
}
/* line 23, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-default:active, #author-comment-card .btn-default.active, .open > #author-comment-card .btn-default.dropdown-toggle {
  color: #333 !important;
  background-color: #e6e6e6 !important;
  border-color: #adadad !important;
}
/* line 30, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-default:active:hover, #author-comment-card .btn-default:active:focus, #author-comment-card .btn-default:active.focus, #author-comment-card .btn-default.active:hover, #author-comment-card .btn-default.active:focus, #author-comment-card .btn-default.active.focus, .open > #author-comment-card .btn-default.dropdown-toggle:hover, .open > #author-comment-card .btn-default.dropdown-toggle:focus, .open > #author-comment-card .btn-default.dropdown-toggle.focus {
  color: #333 !important;
  background-color: #d4d4d4 !important;
  border-color: #8c8c8c !important;
}
/* line 38, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-default:active, #author-comment-card .btn-default.active, .open > #author-comment-card .btn-default.dropdown-toggle {
  background-image: none !important;
}
/* line 46, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-default.disabled:hover, #author-comment-card .btn-default.disabled:focus, #author-comment-card .btn-default.disabled.focus, #author-comment-card .btn-default[disabled]:hover, #author-comment-card .btn-default[disabled]:focus, #author-comment-card .btn-default[disabled].focus, fieldset[disabled] #author-comment-card .btn-default:hover, fieldset[disabled] #author-comment-card .btn-default:focus, fieldset[disabled] #author-comment-card .btn-default.focus {
  background-color: #fff !important;
  border-color: #ccc !important;
}
/* line 54, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-default .badge {
  color: #fff !important;
  background-color: #333 !important;
}
/* line 91, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-primary {
  color: #fff !important;
  background-color: #337ab7 !important;
  border-color: #2e6da4 !important;
}
/* line 12, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-primary:focus, #author-comment-card .btn-primary.focus {
  color: #fff !important;
  background-color: #286090 !important;
  border-color: #122b40 !important;
}
/* line 18, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-primary:hover {
  color: #fff !important;
  background-color: #286090 !important;
  border-color: #204d74;
}
/* line 23, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-primary:active, #author-comment-card .btn-primary.active, .open > #author-comment-card .btn-primary.dropdown-toggle {
  color: #fff !important;
  background-color: #286090 !important;
  border-color: #204d74 !important;
}
/* line 30, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-primary:active:hover, #author-comment-card .btn-primary:active:focus, #author-comment-card .btn-primary:active.focus, #author-comment-card .btn-primary.active:hover, #author-comment-card .btn-primary.active:focus, #author-comment-card .btn-primary.active.focus, .open > #author-comment-card .btn-primary.dropdown-toggle:hover, .open > #author-comment-card .btn-primary.dropdown-toggle:focus, .open > #author-comment-card .btn-primary.dropdown-toggle.focus {
  color: #fff !important;
  background-color: #204d74 !important;
  border-color: #122b40 !important;
}
/* line 38, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-primary:active, #author-comment-card .btn-primary.active, .open > #author-comment-card .btn-primary.dropdown-toggle {
  background-image: none !important;
}
/* line 46, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-primary.disabled:hover, #author-comment-card .btn-primary.disabled:focus, #author-comment-card .btn-primary.disabled.focus, #author-comment-card .btn-primary[disabled]:hover, #author-comment-card .btn-primary[disabled]:focus, #author-comment-card .btn-primary[disabled].focus, fieldset[disabled] #author-comment-card .btn-primary:hover, fieldset[disabled] #author-comment-card .btn-primary:focus, fieldset[disabled] #author-comment-card .btn-primary.focus {
  background-color: #337ab7 !important;
  border-color: #2e6da4 !important;
}
/* line 54, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-primary .badge {
  color: #337ab7 !important;
  background-color: #fff !important;
}
/* line 95, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-success {
  color: #fff !important;
  background-color: #5cb85c !important;
  border-color: #4cae4c !important;
}
/* line 12, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-success:focus, #author-comment-card .btn-success.focus {
  color: #fff !important;
  background-color: #449d44 !important;
  border-color: #255625 !important;
}
/* line 18, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-success:hover {
  color: #fff !important;
  background-color: #449d44 !important;
  border-color: #398439;
}
/* line 23, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-success:active, #author-comment-card .btn-success.active, .open > #author-comment-card .btn-success.dropdown-toggle {
  color: #fff !important;
  background-color: #449d44 !important;
  border-color: #398439 !important;
}
/* line 30, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-success:active:hover, #author-comment-card .btn-success:active:focus, #author-comment-card .btn-success:active.focus, #author-comment-card .btn-success.active:hover, #author-comment-card .btn-success.active:focus, #author-comment-card .btn-success.active.focus, .open > #author-comment-card .btn-success.dropdown-toggle:hover, .open > #author-comment-card .btn-success.dropdown-toggle:focus, .open > #author-comment-card .btn-success.dropdown-toggle.focus {
  color: #fff !important;
  background-color: #398439 !important;
  border-color: #255625 !important;
}
/* line 38, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-success:active, #author-comment-card .btn-success.active, .open > #author-comment-card .btn-success.dropdown-toggle {
  background-image: none !important;
}
/* line 46, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-success.disabled:hover, #author-comment-card .btn-success.disabled:focus, #author-comment-card .btn-success.disabled.focus, #author-comment-card .btn-success[disabled]:hover, #author-comment-card .btn-success[disabled]:focus, #author-comment-card .btn-success[disabled].focus, fieldset[disabled] #author-comment-card .btn-success:hover, fieldset[disabled] #author-comment-card .btn-success:focus, fieldset[disabled] #author-comment-card .btn-success.focus {
  background-color: #5cb85c !important;
  border-color: #4cae4c !important;
}
/* line 54, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-success .badge {
  color: #5cb85c !important;
  background-color: #fff !important;
}
/* line 99, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-info {
  color: #fff !important;
  background-color: #5bc0de !important;
  border-color: #46b8da !important;
}
/* line 12, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-info:focus, #author-comment-card .btn-info.focus {
  color: #fff !important;
  background-color: #31b0d5 !important;
  border-color: #1b6d85 !important;
}
/* line 18, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-info:hover {
  color: #fff !important;
  background-color: #31b0d5 !important;
  border-color: #269abc;
}
/* line 23, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-info:active, #author-comment-card .btn-info.active, .open > #author-comment-card .btn-info.dropdown-toggle {
  color: #fff !important;
  background-color: #31b0d5 !important;
  border-color: #269abc !important;
}
/* line 30, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-info:active:hover, #author-comment-card .btn-info:active:focus, #author-comment-card .btn-info:active.focus, #author-comment-card .btn-info.active:hover, #author-comment-card .btn-info.active:focus, #author-comment-card .btn-info.active.focus, .open > #author-comment-card .btn-info.dropdown-toggle:hover, .open > #author-comment-card .btn-info.dropdown-toggle:focus, .open > #author-comment-card .btn-info.dropdown-toggle.focus {
  color: #fff !important;
  background-color: #269abc !important;
  border-color: #1b6d85 !important;
}
/* line 38, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-info:active, #author-comment-card .btn-info.active, .open > #author-comment-card .btn-info.dropdown-toggle {
  background-image: none !important;
}
/* line 46, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-info.disabled:hover, #author-comment-card .btn-info.disabled:focus, #author-comment-card .btn-info.disabled.focus, #author-comment-card .btn-info[disabled]:hover, #author-comment-card .btn-info[disabled]:focus, #author-comment-card .btn-info[disabled].focus, fieldset[disabled] #author-comment-card .btn-info:hover, fieldset[disabled] #author-comment-card .btn-info:focus, fieldset[disabled] #author-comment-card .btn-info.focus {
  background-color: #5bc0de !important;
  border-color: #46b8da !important;
}
/* line 54, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-info .badge {
  color: #5bc0de !important;
  background-color: #fff !important;
}
/* line 103, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-warning {
  color: #fff !important;
  background-color: #f0ad4e !important;
  border-color: #eea236 !important;
}
/* line 12, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-warning:focus, #author-comment-card .btn-warning.focus {
  color: #fff !important;
  background-color: #ec971f !important;
  border-color: #985f0d !important;
}
/* line 18, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-warning:hover {
  color: #fff !important;
  background-color: #ec971f !important;
  border-color: #d58512;
}
/* line 23, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-warning:active, #author-comment-card .btn-warning.active, .open > #author-comment-card .btn-warning.dropdown-toggle {
  color: #fff !important;
  background-color: #ec971f !important;
  border-color: #d58512 !important;
}
/* line 30, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-warning:active:hover, #author-comment-card .btn-warning:active:focus, #author-comment-card .btn-warning:active.focus, #author-comment-card .btn-warning.active:hover, #author-comment-card .btn-warning.active:focus, #author-comment-card .btn-warning.active.focus, .open > #author-comment-card .btn-warning.dropdown-toggle:hover, .open > #author-comment-card .btn-warning.dropdown-toggle:focus, .open > #author-comment-card .btn-warning.dropdown-toggle.focus {
  color: #fff !important;
  background-color: #d58512 !important;
  border-color: #985f0d !important;
}
/* line 38, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-warning:active, #author-comment-card .btn-warning.active, .open > #author-comment-card .btn-warning.dropdown-toggle {
  background-image: none !important;
}
/* line 46, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-warning.disabled:hover, #author-comment-card .btn-warning.disabled:focus, #author-comment-card .btn-warning.disabled.focus, #author-comment-card .btn-warning[disabled]:hover, #author-comment-card .btn-warning[disabled]:focus, #author-comment-card .btn-warning[disabled].focus, fieldset[disabled] #author-comment-card .btn-warning:hover, fieldset[disabled] #author-comment-card .btn-warning:focus, fieldset[disabled] #author-comment-card .btn-warning.focus {
  background-color: #f0ad4e !important;
  border-color: #eea236 !important;
}
/* line 54, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-warning .badge {
  color: #f0ad4e !important;
  background-color: #fff !important;
}
/* line 107, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-danger {
  color: #fff !important;
  background-color: #d9534f !important;
  border-color: #d43f3a !important;
}
/* line 12, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-danger:focus, #author-comment-card .btn-danger.focus {
  color: #fff !important;
  background-color: #c9302c !important;
  border-color: #761c19 !important;
}
/* line 18, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-danger:hover {
  color: #fff !important;
  background-color: #c9302c !important;
  border-color: #ac2925;
}
/* line 23, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-danger:active, #author-comment-card .btn-danger.active, .open > #author-comment-card .btn-danger.dropdown-toggle {
  color: #fff !important;
  background-color: #c9302c !important;
  border-color: #ac2925 !important;
}
/* line 30, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-danger:active:hover, #author-comment-card .btn-danger:active:focus, #author-comment-card .btn-danger:active.focus, #author-comment-card .btn-danger.active:hover, #author-comment-card .btn-danger.active:focus, #author-comment-card .btn-danger.active.focus, .open > #author-comment-card .btn-danger.dropdown-toggle:hover, .open > #author-comment-card .btn-danger.dropdown-toggle:focus, .open > #author-comment-card .btn-danger.dropdown-toggle.focus {
  color: #fff !important;
  background-color: #ac2925 !important;
  border-color: #761c19 !important;
}
/* line 38, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-danger:active, #author-comment-card .btn-danger.active, .open > #author-comment-card .btn-danger.dropdown-toggle {
  background-image: none !important;
}
/* line 46, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-danger.disabled:hover, #author-comment-card .btn-danger.disabled:focus, #author-comment-card .btn-danger.disabled.focus, #author-comment-card .btn-danger[disabled]:hover, #author-comment-card .btn-danger[disabled]:focus, #author-comment-card .btn-danger[disabled].focus, fieldset[disabled] #author-comment-card .btn-danger:hover, fieldset[disabled] #author-comment-card .btn-danger:focus, fieldset[disabled] #author-comment-card .btn-danger.focus {
  background-color: #d9534f !important;
  border-color: #d43f3a !important;
}
/* line 54, ../scss/_light-bootstrap.scss */
#author-comment-card .btn-danger .badge {
  color: #d9534f !important;
  background-color: #fff !important;
}

/* line 2, ../scss/admin-without-bootstrap.scss */
#author-comment-card {
  margin-bottom: 20px;
  width: 80%;
}
/* line 5, ../scss/admin-without-bootstrap.scss */
#author-comment-card .avatar {
  vertical-align: top;
}
/* line 9, ../scss/admin-without-bootstrap.scss */
#author-comment-card .author-comment-info {
  display: inline-block;
}
/* line 13, ../scss/admin-without-bootstrap.scss */
#author-comment-card #controls {
  float: right;
}
/* line 15, ../scss/admin-without-bootstrap.scss */
#author-comment-card #controls .btn-group {
  float: right;
}
/* line 18, ../scss/admin-without-bootstrap.scss */
#author-comment-card #controls .is-moderated {
  color: #985f0d;
  clear: both;
  padding-top: 10px;
}

/* line 29, ../scss/admin-without-bootstrap.scss */
#toggle_soft_delete.delete {
  color: #fff !important;
  background: #d9534f !important;
}
/* line 34, ../scss/admin-without-bootstrap.scss */
#toggle_soft_delete.restore {
  color: #fff !important;
  background: #5cb85c !important;
}
